"""django-auth-wall - Puts your staging site behind a basic auth layer."""

__version__ = "0.3.0"
__author__ = "Saurabh Kumar <saurabh@saurabh-kumar.com>"

# Header encoding (see RFC5987)
HTTP_HEADER_ENCODING = "iso-8859-1"
